@@ -5,8 +5,7 @@
 
 """Implementation of gas ls."""
 
-import sys
-from typing import Dict, Iterable, Optional
+from typing import Iterable, Optional
 
 import click
 
@@ -14,7 +13,7 @@ from ..client import GAS
 from ..client.dataset import FusionDatasetClient
 from ..client.gas import DatasetClientType
 from .tbrn import TBRN, TBRNType
-from .utility import get_dataset_client, get_gas
+from .utility import ContextInfo, error, get_dataset_client, get_gas
 
 
 def _echo_data(
@@ -48,59 +47,71 @@ def _echo_data(
 
 def _validate_dataset_client(dataset_client: DatasetClientType) -> None:
     if not dataset_client.status.draft_number and not dataset_client.status.commit_id:
-        click.echo(f'"{dataset_client.name}" has no commit history.', err=True)
-        sys.exit(1)
+        error(f'"{dataset_client.name}" has no commit history.')
 
 
-def _ls_dataset(gas: GAS, info: TBRN, list_all_files: bool) -> None:
+def _ls_dataset(gas: GAS, info: TBRN, list_all_files: bool, show_total_num: bool) -> None:
     dataset_client = get_dataset_client(gas, info)
     _validate_dataset_client(dataset_client)
 
     segment_names = dataset_client.list_segment_names()
     if not list_all_files:
+        if show_total_num:
+            click.echo(f"total {len(segment_names)}")
         for segment_name in segment_names:
             click.echo(TBRN(info.dataset_name, segment_name).get_tbrn())
         return
 
     if isinstance(dataset_client, FusionDatasetClient):
-        click.echo('"-a" flag is not supported for fusion dataset yet', err=True)
-        sys.exit(1)
+        error('"-a" flag is not supported for fusion dataset yet')
 
-    for segment_name in segment_names:
-        segment = dataset_client.get_segment(segment_name)
+    segment_paths = [
+        dataset_client.get_segment(segment_name).list_data_paths() for segment_name in segment_names
+    ]
+    if show_total_num:
+        total = sum(len(segment_path) for segment_path in segment_paths)
+        click.echo(f"total {total}")
+
+    for segment_name, segment_path in zip(segment_names, segment_paths):
         _echo_data(
             info.dataset_name,
             info.draft_number,
             info.revision,
             segment_name,
-            segment.list_data_paths(),
+            segment_path,
         )
 
 
 def _ls_segment(
-    gas: GAS, info: TBRN, list_all_files: bool  # pylint: disable=unused-argument
+    gas: GAS,
+    info: TBRN,
+    list_all_files: bool,  # pylint: disable=unused-argument
+    show_total_num: bool,
 ) -> None:
     dataset_client = get_dataset_client(gas, info)
     _validate_dataset_client(dataset_client)
     if isinstance(dataset_client, FusionDatasetClient):
-        click.echo("List fusion segment is not supported yet", err=True)
-        sys.exit(1)
+        error("List fusion segment is not supported yet")
 
-    segment = dataset_client.get_segment(info.segment_name)
+    segment_path = dataset_client.get_segment(info.segment_name).list_data_paths()
+    if show_total_num:
+        click.echo(f"total {len(segment_path)}")
     _echo_data(
         info.dataset_name,
         info.draft_number,
         info.revision,
         info.segment_name,
-        segment.list_data_paths(),
+        segment_path,
     )
 
 
 def _ls_normal_file(
-    gas: GAS, info: TBRN, list_all_files: bool  # pylint: disable=unused-argument
+    gas: GAS,  # pylint: disable=unused-argument
+    info: TBRN,  # pylint: disable=unused-argument
+    list_all_files: bool,  # pylint: disable=unused-argument
+    show_total_num: bool,  # pylint: disable=unused-argument
 ) -> None:
-    click.echo("List for specific file is not supported yet", err=True)
-    sys.exit(1)
+    error("List for specific file is not supported yet")
 
 
 _LS_FUNCS = {
@@ -110,13 +121,15 @@ _LS_FUNCS = {
 }
 
 
-def _implement_ls(obj: Dict[str, str], tbrn: str, list_all_files: bool) -> None:
-    gas = get_gas(**obj)
-
+def _implement_ls(obj: ContextInfo, tbrn: str, list_all_files: bool, show_total_num: bool) -> None:
+    gas = get_gas(*obj)
     if not tbrn:
-        for dataset_name in gas.list_dataset_names():
+        dataset_names = gas.list_dataset_names()
+        if show_total_num:
+            click.echo(f"total {len(dataset_names)}")
+        for dataset_name in dataset_names:
             click.echo(TBRN(dataset_name).get_tbrn())
         return
 
     info = TBRN(tbrn=tbrn)
-    _LS_FUNCS[info.type](gas, info, list_all_files)
+    _LS_FUNCS[info.type](gas, info, list_all_files, show_total_num)
