@@ -23,21 +23,20 @@ for more information.
 
 """
 
-import os
 import time
 from copy import deepcopy
-from hashlib import sha1
-from itertools import islice
-from typing import TYPE_CHECKING, Any, Dict, Generator, Iterable, List, Optional, Union
+from itertools import zip_longest
+from typing import TYPE_CHECKING, Any, Callable, Dict, Generator, Iterable, Optional, Tuple, Union
 
 import filetype
 from requests_toolbelt import MultipartEncoder
 from ulid import from_timestamp
 
 from ..dataset import AuthData, Data, Frame, RemoteData
-from ..exception import FrameError, InvalidParamsError, OperationError, ResponseSystemError
+from ..exception import FrameError, InvalidParamsError, OperationError, ResponseError
+from ..label import Label
 from ..sensor.sensor import Sensor, Sensors
-from ..utility import Disable, locked
+from ..utility import Disable, FileMixin, chunked, locked
 from .lazy import PagingList
 from .requests import config
 from .status import Status
@@ -46,6 +45,15 @@ if TYPE_CHECKING:
     from .dataset import DatasetClient, FusionDatasetClient
 
 _STRATEGIES = {"abort", "override", "skip"}
+_MASK_KEYS = ("semantic_mask", "instance_mask", "panoptic_mask")
+
+
+class _UrlGetters:
+    def __init__(self, urls: PagingList[str]) -> None:
+        self._urls = urls
+
+    def __getitem__(self, index: int) -> Callable[[str], str]:
+        return lambda _: self._urls[index]
 
 
 class SegmentClientBase:  # pylint: disable=too-many-instance-attributes
@@ -65,7 +73,6 @@ class SegmentClientBase:  # pylint: disable=too-many-instance-attributes
     """
 
     _EXPIRED_IN_SECOND = 240
-    _BUF_SIZE = 65536  # lets read stuff in 64kb chunks!
 
     def __init__(
         self, name: str, dataset_client: "Union[DatasetClient, FusionDatasetClient]"
@@ -114,6 +121,21 @@ class SegmentClientBase:  # pylint: disable=too-many-instance-attributes
         response = self._client.open_api_do("GET", "data/urls", self._dataset_id, params=params)
         return response.json()  # type: ignore[no-any-return]
 
+    def _list_mask_urls(self, mask_type: str, offset: int = 0, limit: int = 128) -> Dict[str, Any]:
+        params: Dict[str, Any] = {
+            "segmentName": self._name,
+            "maskType": mask_type,
+            "offset": offset,
+            "limit": limit,
+        }
+        params.update(self._status.get_status_info())
+
+        if config.is_internal:
+            params["isInternal"] = True
+
+        response = self._client.open_api_do("GET", "masks/urls", self._dataset_id, params=params)
+        return response.json()  # type: ignore[no-any-return]
+
     def _list_labels(self, offset: int = 0, limit: int = 128) -> Dict[str, Any]:
         params: Dict[str, Any] = {
             "segmentName": self._name,
@@ -145,34 +167,71 @@ class SegmentClientBase:  # pylint: disable=too-many-instance-attributes
 
         return deepcopy(self._permission)
 
-    def _calculate_file_sha1(self, local_path: str) -> str:
-        sha1_obj = sha1()
-        with open(local_path, "rb") as fp:
-            while True:
-                data = fp.read(self._BUF_SIZE)
-                if not data:
-                    break
-                sha1_obj.update(data)
+    def _upload_file(self, data: FileMixin) -> None:
+        """Upload the file in the data to the draft.
 
-        return sha1_obj.hexdigest()
+        Arguments:
+            data: The data instance needs to be uploaded.
+
+        """
+        permission = self._get_upload_permission()
+        post_data = permission["result"]
+
+        local_path = data.path
+        checksum = data.get_checksum()
+
+        post_data["key"] = permission["extra"]["objectPrefix"] + checksum
+
+        backend_type = permission["extra"]["backendType"]
+        if backend_type == "azure":
+            url = (
+                f'{permission["extra"]["host"]}{permission["extra"]["objectPrefix"]}'
+                f'{checksum}?{permission["result"]["token"]}'
+            )
+
+            self._put_binary_file_to_azure(url, local_path, post_data)
+        else:
+            self._post_multipart_formdata(
+                permission["extra"]["host"],
+                local_path,
+                post_data,
+            )
+
+    def _upload_mask_files(self, label: Label) -> None:
+        for key in _MASK_KEYS:
+            mask = getattr(label, key, None)
+            if mask:
+                self._upload_file(mask)
 
     def _post_multipart_formdata(
         self,
         url: str,
         local_path: str,
-        remote_path: str,
         data: Dict[str, Any],
     ) -> None:
         with open(local_path, "rb") as fp:
             file_type = filetype.guess_mime(local_path)
             if "x-amz-date" in data:
                 data["Content-Type"] = file_type
-            data["file"] = (remote_path, fp, file_type)
-            multipart = MultipartEncoder(data)
 
-            self._client.do(
-                "POST", url, data=multipart, headers={"Content-Type": multipart.content_type}
-            )
+            try:
+                data["file"] = ("", fp, file_type)
+                self._post_formdata(url, data)
+            except ResponseError as error:
+                if b"MalformedPOSTRequest" in error.response.content:
+                    data["file"] = ("workaroundForMalformedPostRequest", fp, file_type)
+                    self._post_formdata(url, data)
+                else:
+                    raise
+
+    def _post_formdata(self, url: str, data: Dict[str, Any]) -> None:
+        multipart = MultipartEncoder(data)
+        self._client.do(
+            "POST",
+            url,
+            data=multipart,
+            headers={"Content-Type": multipart.content_type},
+        )
 
     def _put_binary_file_to_azure(
         self,
@@ -190,20 +249,15 @@ class SegmentClientBase:  # pylint: disable=too-many-instance-attributes
 
     def _synchronize_upload_info(
         self,
-        callback_info: List[Dict[str, Any]],
-        skip_uploaded_files: bool = False,
+        callback_bodies: Tuple[Dict[str, Any], ...],
     ) -> None:
         put_data: Dict[str, Any] = {
             "segmentName": self.name,
-            "objects": callback_info,
+            "objects": callback_bodies,
         }
         put_data.update(self._status.get_status_info())
 
-        try:
-            self._client.open_api_do("PUT", "multi/callback", self._dataset_id, json=put_data)
-        except ResponseSystemError:
-            if not skip_uploaded_files:
-                raise
+        self._client.open_api_do("PUT", "multi/callback", self._dataset_id, json=put_data)
 
     def _import_cloud_file(
         self,
@@ -253,7 +307,7 @@ class SegmentClientBase:  # pylint: disable=too-many-instance-attributes
         """
         return self._status
 
-    @Disable(since="v1.6.0", enabled_in="v1.9.0", reason="TensorBay server refactor")
+    @Disable(since="v1.6.0", enabled_in="v1.12.0", reason="TensorBay server refactor")
     def delete_data(self, remote_paths: Union[str, Iterable[str]]) -> None:
         """Delete data of a segment in a certain commit with the given remote paths.
 
@@ -265,10 +319,7 @@ class SegmentClientBase:  # pylint: disable=too-many-instance-attributes
 
         all_paths = iter((remote_paths,)) if isinstance(remote_paths, str) else iter(remote_paths)
 
-        while True:
-            request_remote_paths = list(islice(all_paths, 128))
-            if not request_remote_paths:
-                return
+        for request_remote_paths in chunked(all_paths, 128):
             delete_data: Dict[str, Any] = {
                 "segmentName": self.name,
                 "remotePaths": request_remote_paths,
@@ -308,14 +359,20 @@ class SegmentClient(SegmentClientBase):
         return response["totalCount"]  # type: ignore[no-any-return]
 
     def _generate_data(
-        self, urls: PagingList[str], offset: int = 0, limit: int = 128
+        self, url_getters: Dict[str, _UrlGetters], offset: int = 0, limit: int = 128
     ) -> Generator[RemoteData, None, int]:
         response = self._list_labels(offset, limit)
+        urls = url_getters["file"]
 
         for i, item in enumerate(response["labels"], offset):
-            data = RemoteData.loads(item)
-            # pylint: disable=protected-access
-            data._url_getter = lambda _, i=i: urls[i]  # type: ignore[misc]
+            data = RemoteData.from_response_body(item, _url_getter=urls[i])
+            label = data.label
+            for key in _MASK_KEYS:
+                mask = getattr(label, key, None)
+                if mask:
+                    # pylint: disable=protected-access
+                    mask._url_getter = url_getters[key][i]
+
             yield data
 
         return response["totalCount"]  # type: ignore[no-any-return]
@@ -328,59 +385,25 @@ class SegmentClient(SegmentClientBase):
 
         return response["totalCount"]  # type: ignore[no-any-return]
 
+    def _generate_mask_urls(
+        self, mask_type: str, offset: int = 0, limit: int = 128
+    ) -> Generator[str, None, int]:
+        response = self._list_mask_urls(mask_type, offset, limit)
+
+        for item in response["urls"]:
+            yield item["url"]
+
+        return response["totalCount"]  # type: ignore[no-any-return]
+
     def _upload_or_import_data(self, data: Union[Data, AuthData]) -> Optional[Dict[str, Any]]:
         if isinstance(data, Data):
-            callback_info = self._upload_file(data.path, data.target_remote_path)
-            if data.label:
-                callback_info["label"] = data.label.dumps()
-            return callback_info
+            self._upload_file(data)
+            self._upload_mask_files(data.label)
+            return data.get_callback_body()
+
         self.import_auth_data(data)
         return None
 
-    def _upload_file(self, local_path: str, target_remote_path: str = "") -> Dict[str, Any]:
-        """Upload data with local path to the draft.
-
-        Arguments:
-            local_path: The local path of the data to upload.
-            target_remote_path: The path to save the data in segment client.
-
-        Returns:
-            The sha1 and target remote path of the file.
-
-        Raises:
-            InvalidParamsError: When target_remote_path does not follow linux style.
-
-        """
-        if not target_remote_path:
-            target_remote_path = os.path.basename(local_path)
-
-        if "\\" in target_remote_path:
-            raise InvalidParamsError(param_name="path", param_value=target_remote_path)
-
-        permission = self._get_upload_permission()
-        post_data = permission["result"]
-
-        checksum = self._calculate_file_sha1(local_path)
-        post_data["key"] = permission["extra"]["objectPrefix"] + checksum
-
-        backend_type = permission["extra"]["backendType"]
-        if backend_type == "azure":
-            url = (
-                f'{permission["extra"]["host"]}{permission["extra"]["objectPrefix"]}'
-                f'{checksum}?{permission["result"]["token"]}'
-            )
-
-            self._put_binary_file_to_azure(url, local_path, post_data)
-        else:
-            self._post_multipart_formdata(
-                permission["extra"]["host"],
-                local_path,
-                target_remote_path,
-                post_data,
-            )
-
-        return {"checksum": checksum, "remotePath": target_remote_path}
-
     def upload_file(self, local_path: str, target_remote_path: str = "") -> None:
         """Upload data with local path to the draft.
 
@@ -391,9 +414,10 @@ class SegmentClient(SegmentClientBase):
         """
         self._status.check_authority_for_draft()
 
-        callback_info = self._upload_file(local_path, target_remote_path)
+        data = Data(local_path, target_remote_path=target_remote_path)
+        self._upload_file(data)
 
-        self._synchronize_upload_info([callback_info])
+        self._synchronize_upload_info((data.get_callback_body(),))
 
     def upload_label(self, data: Data) -> None:
         """Upload label with Data object to the draft.
@@ -404,6 +428,7 @@ class SegmentClient(SegmentClientBase):
         """
         self._status.check_authority_for_draft()
 
+        self._upload_mask_files(data.label)
         self._upload_label(data)
 
     def upload_data(self, data: Data) -> None:
@@ -414,11 +439,9 @@ class SegmentClient(SegmentClientBase):
 
         """
         self._status.check_authority_for_draft()
-
-        callback_info = self._upload_file(data.path, data.target_remote_path)
-        if data.label:
-            callback_info["label"] = data.label.dumps()
-        self._synchronize_upload_info([callback_info])
+        self._upload_file(data)
+        self._upload_mask_files(data.label)
+        self._synchronize_upload_info((data.get_callback_body(),))
 
     def import_auth_data(self, data: AuthData) -> None:
         """Import AuthData object to the draft.
@@ -509,13 +532,12 @@ class SegmentClient(SegmentClientBase):
         }
         post_data.update(self._status.get_status_info())
 
-        for start in range(0, len(all_source_remote_paths), 128):
-            request_target_remote_paths = all_target_remote_paths[start : start + 128]
-            request_source_remote_paths = all_source_remote_paths[start : start + 128]
-
-            if request_target_remote_paths:
-                post_data["remotePaths"] = request_target_remote_paths
-            post_data["source"]["remotePaths"] = request_source_remote_paths
+        for targets, sources in zip_longest(
+            chunked(all_target_remote_paths, 128), chunked(all_source_remote_paths, 128)
+        ):
+            if targets:
+                post_data["remotePaths"] = targets
+            post_data["source"]["remotePaths"] = sources
 
             self._client.open_api_do("POST", "data?multipleCopy", self._dataset_id, json=post_data)
 
@@ -525,6 +547,7 @@ class SegmentClient(SegmentClientBase):
         target_remote_paths: Union[None, str, Iterable[str]] = None,
         *,
         source_client: Optional["SegmentClient"] = None,
+        strategy: str = "abort",
     ) -> None:
         """Move data to this segment, also used to rename data.
 
@@ -537,8 +560,14 @@ class SegmentClient(SegmentClientBase):
                 This argument is used to specifies where the moved data comes from when the moved
                 data is from another segment.
                 If None, the moved data comes from this segment.
+            strategy: The strategy of handling the name conflict. There are three options:
+
+                1. "abort": stop copying and raise exception;
+                2. "override": the source data will override the origin data;
+                3. "skip": keep the origin data.
 
         Raises:
+            InvalidParamsError: When strategy is invalid.
             OperationError: When the type or the length of target_remote_paths is not equal
                 with source_remote_paths.
                 Or when the dataset_id and drafter_number of source_client
@@ -547,6 +576,9 @@ class SegmentClient(SegmentClientBase):
         """
         self._status.check_authority_for_draft()
 
+        if strategy not in _STRATEGIES:
+            raise InvalidParamsError(param_name="strategy", param_value=strategy)
+
         if not target_remote_paths:
             all_target_remote_paths = []
             all_source_remote_paths = (
@@ -590,18 +622,18 @@ class SegmentClient(SegmentClientBase):
             source["segmentName"] = self.name
 
         post_data: Dict[str, Any] = {
+            "strategy": strategy,
             "source": source,
             "segmentName": self.name,
         }
         post_data.update(self._status.get_status_info())
 
-        for start in range(0, len(all_source_remote_paths), 128):
-            request_target_remote_paths = all_target_remote_paths[start : start + 128]
-            request_source_remote_paths = all_source_remote_paths[start : start + 128]
-
-            if request_target_remote_paths:
-                post_data["remotePaths"] = request_target_remote_paths
-            post_data["source"]["remotePaths"] = request_source_remote_paths
+        for targets, sources in zip_longest(
+            chunked(all_target_remote_paths, 128), chunked(all_source_remote_paths, 128)
+        ):
+            if targets:
+                post_data["remotePaths"] = targets
+            post_data["source"]["remotePaths"] = sources
 
             self._client.open_api_do("POST", "data?multipleMove", self._dataset_id, json=post_data)
 
@@ -621,8 +653,13 @@ class SegmentClient(SegmentClientBase):
             The PagingList of :class:`~tensorbay.dataset.data.RemoteData`.
 
         """
-        urls = self.list_urls()
-        return PagingList(lambda offset, limit: self._generate_data(urls, offset, limit), 128)
+        url_getters = {"file": _UrlGetters(self.list_urls())}
+        for key in _MASK_KEYS:
+            url_getters[key] = _UrlGetters(self.list_mask_urls(key.upper()))
+
+        return PagingList(
+            lambda offset, limit: self._generate_data(url_getters, offset, limit), 128
+        )
 
     def list_urls(self) -> PagingList[str]:
         """List the data urls in this segment.
@@ -633,6 +670,21 @@ class SegmentClient(SegmentClientBase):
         """
         return PagingList(self._generate_urls, 128)
 
+    def list_mask_urls(self, mask_type: str) -> PagingList[str]:
+        """List the mask urls in this segment.
+
+        Arguments:
+            mask_type: The required mask type, the supported types are
+                ``SEMANTIC_MASK``, ``INSTANCE_MASK`` and ``PANOPTIC_MASK``
+
+        Returns:
+            The PagingList of mask urls.
+
+        """
+        return PagingList(
+            lambda offset, limit: self._generate_mask_urls(mask_type, offset, limit), 128
+        )
+
 
 class FusionSegmentClient(SegmentClientBase):
     """This class defines :class:`FusionSegmentClient`.
@@ -657,14 +709,8 @@ class FusionSegmentClient(SegmentClientBase):
     ) -> Generator[Frame, None, int]:
         response = self._list_labels(offset, limit)
 
-        data: RemoteData
-        for i, item in enumerate(response["labels"], offset):
-            frame = Frame.loads(item)
-            # pylint: disable=no-member # pylint issue: #3131
-            for sensor_name, data in frame.items():  # type: ignore[assignment]
-                # pylint: disable=protected-access
-                data._url_getter = lambda _, i=i, s=sensor_name: urls[i][s]  # type: ignore[misc]
-            yield frame
+        for index, item in enumerate(response["labels"], offset):
+            yield Frame.from_response_body(item, index, urls)
 
         return response["totalCount"]  # type: ignore[no-any-return]
 
@@ -678,6 +724,22 @@ class FusionSegmentClient(SegmentClientBase):
 
         return response["totalCount"]  # type: ignore[no-any-return]
 
+    def _upload_or_import_data(
+        self,
+        data: Union[Data, AuthData],
+        sensor_name: str,
+        frame_id: str,
+    ) -> Optional[Dict[str, Any]]:
+        if isinstance(data, Data):
+            self._upload_file(data)
+            self._upload_mask_files(data.label)
+
+            callback_body = data.get_callback_body()
+            callback_body["frameId"] = frame_id
+            callback_body["sensorName"] = sensor_name
+            return callback_body
+        return None
+
     def get_sensors(self) -> Sensors:
         """Return the sensors in a fusion segment client.
 
@@ -723,19 +785,15 @@ class FusionSegmentClient(SegmentClientBase):
 
         self._client.open_api_do("DELETE", "sensors", self._dataset_id, json=delete_data)
 
-    def upload_frame(  # pylint: disable=too-many-locals
-        self, frame: Frame, timestamp: Optional[float] = None, skip_uploaded_files: bool = False
-    ) -> None:
+    def upload_frame(self, frame: Frame, timestamp: Optional[float] = None) -> None:
         """Upload frame to the draft.
 
         Arguments:
             frame: The :class:`~tensorbay.dataset.frame.Frame` to upload.
             timestamp: The mark to sort frames, supporting timestamp and float.
-            skip_uploaded_files: Set it to True to skip the uploaded files.
 
         Raises:
             FrameError: When lacking frame id or frame id conflicts.
-            InvalidParamsError: When remote_path does not follow linux style.
 
         """
         self._status.check_authority_for_draft()
@@ -753,51 +811,21 @@ class FusionSegmentClient(SegmentClientBase):
         else:
             raise FrameError("Frame id conflicts, please do not give timestamp to the function!.")
 
+        callback_bodies = []
         for sensor_name, data in frame.items():
             if not isinstance(data, Data):
                 continue
 
-            target_remote_path = data.target_remote_path
+            self._upload_file(data)
+            self._upload_mask_files(data.label)
 
-            if "\\" in target_remote_path:
-                raise InvalidParamsError(param_name="path", param_value=target_remote_path)
+            callback_body = data.get_callback_body()
+            callback_body["frameId"] = frame_id.str
+            callback_body["sensorName"] = sensor_name
+            callback_bodies.append(callback_body)
 
-            permission = self._get_upload_permission()
-            post_data = permission["result"]
-
-            checksum = self._calculate_file_sha1(data.path)
-            post_data["key"] = permission["extra"]["objectPrefix"] + checksum
-
-            backend_type = permission["extra"]["backendType"]
-            if backend_type == "azure":
-                url = (
-                    f'{permission["extra"]["host"]}{permission["extra"]["objectPrefix"]}'
-                    f'{checksum}?{permission["result"]["token"]}'
-                )
-
-                self._put_binary_file_to_azure(url, data.path, post_data)
-            else:
-                self._post_multipart_formdata(
-                    permission["extra"]["host"],
-                    data.path,
-                    target_remote_path,
-                    post_data,
-                )
-
-            frame_info: Dict[str, Any] = {
-                "sensorName": sensor_name,
-                "frameId": str(frame_id),
-            }
-            if hasattr(data, "timestamp"):
-                frame_info["timestamp"] = data.timestamp
-
-            callback_info = {
-                "checksum": checksum,
-                "remotePath": target_remote_path,
-                "label": data.label.dumps(),
-            }
-            callback_info.update(frame_info)
-            self._synchronize_upload_info([callback_info], skip_uploaded_files)
+        for chunked_callback_bodies in chunked(callback_bodies, 50):
+            self._synchronize_upload_info(chunked_callback_bodies)
 
     def list_frames(self) -> PagingList[Frame]:
         """List required frames in the segment in a certain commit.
