@@ -5,7 +5,7 @@
 
 """TensorBay dataset version control related classes."""
 
-from typing import TYPE_CHECKING, Any, Dict, Generator, Optional
+from typing import TYPE_CHECKING, Any, Dict, Generator, Optional, Union
 
 from ..exception import OperationError, ResourceNotExistError, StatusError
 from .lazy import PagingList
@@ -31,6 +31,25 @@ class VersionControlClient:
         self._client = gas._client  # pylint: disable=protected-access
         self._status = status
 
+    def _get_basehead(
+        self, base: Optional[Union[str, int]] = None, head: Optional[Union[str, int]] = None
+    ) -> str:
+        if head:
+            head = f"draft-{head}" if isinstance(head, int) else f"commit-{head}"
+        else:
+            if self._status.is_draft:
+                head = f"draft-{self.status.draft_number}"
+            else:
+                head = f"commit-{self.status.commit_id}"
+
+        if base:
+            base = f"draft-{base}" if isinstance(base, int) else f"commit-{base}"
+            basehead = f"{base}...{head}"
+        else:
+            basehead = head
+
+        return basehead
+
     def _commit(self, title: str, description: str, tag: Optional[str] = None) -> str:
         post_data: Dict[str, Any] = {"title": title}
         post_data.update(self._status.get_status_info())
