@@ -3,10 +3,7 @@
 # Copyright 2021 Graviti. Licensed under MIT License.
 #
 
-"""LabelType, SubcatalogBase.
-
-:class:`LabelType` is an enumeration type
-which includes all the supported label types within :class:`Label`.
+"""SubcatalogBase.
 
 :class:`Subcatalogbase` is the base class for different types of subcatalogs,
 which defines the basic concept of Subcatalog.
@@ -17,52 +14,10 @@ A subcatalog class extends :class:`SubcatalogBase` and needed :class:`Subcatalog
 
 from typing import Any, Dict, List, Optional, Tuple, Type, TypeVar, Union
 
-from ..utility import AttrsMixin, ReprMixin, ReprType, TypeEnum, TypeMixin, attr, common_loads
+from ..utility import AttrsMixin, ReprMixin, ReprType, attr, common_loads
 
 
-class LabelType(TypeEnum):
-    """This class defines all the supported types within :class:`Label`.
-
-    Examples:
-        >>> LabelType.BOX3D
-        <LabelType.BOX3D: 'box3d'>
-        >>> LabelType["BOX3D"]
-        <LabelType.BOX3D: 'box3d'>
-        >>> LabelType.BOX3D.name
-        'BOX3D'
-        >>> LabelType.BOX3D.value
-        'box3d'
-
-    """
-
-    __subcatalog_registry__: Dict[TypeEnum, Type[Any]] = {}
-
-    CLASSIFICATION = "classification"
-    BOX2D = "box2d"
-    BOX3D = "box3d"
-    POLYGON2D = "polygon2d"
-    POLYLINE2D = "polyline2d"
-    KEYPOINTS2D = "keypoints2d"
-    SENTENCE = "sentence"
-
-    @property
-    def subcatalog_type(self) -> Type[Any]:
-        """Return the corresponding subcatalog class.
-
-        Each label type has a corresponding Subcatalog class.
-
-        Returns:
-            The corresponding subcatalog type.
-
-        Examples:
-            >>> LabelType.BOX3D.subcatalog_type
-            <class 'tensorbay.label.label_box.Box3DSubcatalog'>
-
-        """
-        return self.__subcatalog_registry__[self]
-
-
-class SubcatalogBase(TypeMixin[LabelType], ReprMixin, AttrsMixin):
+class SubcatalogBase(ReprMixin, AttrsMixin):
     """This is the base class for different types of subcatalogs.
 
     It defines the basic concept of Subcatalog, which is the collection of the labels information.
@@ -81,7 +36,7 @@ class SubcatalogBase(TypeMixin[LabelType], ReprMixin, AttrsMixin):
     _T = TypeVar("_T", bound="SubcatalogBase")
 
     _repr_type = ReprType.INSTANCE
-    _repr_attrs = (
+    _repr_attrs: Tuple[str, ...] = (
         "is_sample",
         "sample_rate",
         "is_tracking",
@@ -119,7 +74,10 @@ class SubcatalogBase(TypeMixin[LabelType], ReprMixin, AttrsMixin):
         return self._dumps()
 
 
-class _LabelBase(AttrsMixin, TypeMixin[LabelType], ReprMixin):
+AttributeType = Dict[str, Union[str, int, float, bool, List[Union[str, int, float, bool]]]]
+
+
+class _LabelBase(AttrsMixin, ReprMixin):
     """This class defines the basic concept of label.
 
     :class:`_LabelBase` is the most basic label level in the TensorBay dataset structure,
@@ -140,20 +98,16 @@ class _LabelBase(AttrsMixin, TypeMixin[LabelType], ReprMixin):
 
     """
 
-    _label_attrs: Tuple[str, ...] = ("category", "attributes", "instance")
-
-    _repr_attrs = _label_attrs
-
-    _AttributeType = Dict[str, Union[str, int, float, bool, List[Union[str, int, float, bool]]]]
+    _repr_attrs: Tuple[str, ...] = ("category", "attributes", "instance")
 
     category: str = attr(is_dynamic=True)
-    attributes: _AttributeType = attr(is_dynamic=True)
+    attributes: AttributeType = attr(is_dynamic=True)
     instance: str = attr(is_dynamic=True)
 
     def __init__(
         self,
         category: Optional[str] = None,
-        attributes: Optional[_AttributeType] = None,
+        attributes: Optional[AttributeType] = None,
         instance: Optional[str] = None,
     ):
         if category:
