@@ -15,15 +15,12 @@ which is often used for CV tasks such as human body pose estimation.
 from typing import Any, Dict, Iterable, List, Optional, Type, TypeVar, Union
 
 from ..geometry import Keypoints2D
-from ..utility import ReprType, SubcatalogTypeRegister, TypeRegister, common_loads
-from .basic import LabelType, SubcatalogBase, _LabelBase
+from ..utility import ReprType, attr, attr_base, common_loads
+from .basic import SubcatalogBase, _LabelBase
 from .supports import AttributesMixin, CategoriesMixin, IsTrackingMixin, KeypointsInfo
 
 
-@SubcatalogTypeRegister(LabelType.KEYPOINTS2D)
-class Keypoints2DSubcatalog(  # pylint: disable=too-many-ancestors
-    SubcatalogBase, IsTrackingMixin, CategoriesMixin, AttributesMixin
-):
+class Keypoints2DSubcatalog(SubcatalogBase, IsTrackingMixin, CategoriesMixin, AttributesMixin):
     """This class defines the subcatalog for 2D keypoints type of labels.
 
     Arguments:
@@ -33,12 +30,12 @@ class Keypoints2DSubcatalog(  # pylint: disable=too-many-ancestors
     Attributes:
         description: The description of the entire 2D keypoints subcatalog.
         categories: All the possible categories in the corresponding dataset
-            stored in a :class:`~tensorbay.utility.name.NameOrderedDict`
+            stored in a :class:`~tensorbay.utility.name.NameList`
             with the category names as keys
             and the :class:`~tensorbay.label.supports.CategoryInfo` as values.
         category_delimiter: The delimiter in category values indicating parent-child relationship.
         attributes: All the possible attributes in the corresponding dataset
-            stored in a :class:`~tensorbay.utility.name.NameOrderedDict`
+            stored in a :class:`~tensorbay.utility.name.NameList`
             with the attribute names as keys
             and the :class:`~tensorbay.label.attribute.AttributeInfo` as values.
         is_tracking: Whether the Subcatalog contains tracking information.
@@ -64,17 +61,17 @@ class Keypoints2DSubcatalog(  # pylint: disable=too-many-ancestors
         Keypoints2DSubcatalog(
           (is_tracking): True,
           (keypoints): [...],
-          (categories): NameOrderedDict {...},
-          (attributes): NameOrderedDict {...}
+          (categories): NameList [...],
+          (attributes): NameList [...]
         )
 
         *Initialization Method 2:* Init an empty Keypoints2DSubcatalog and then add the attributes.
 
         >>> from tensorbay.label import CategoryInfo, AttributeInfo, KeypointsInfo
-        >>> from tensorbay.utility import NameOrderedDict
-        >>> categories = NameOrderedDict()
+        >>> from tensorbay.utility import NameList
+        >>> categories = NameList()
         >>> categories.append(CategoryInfo("a"))
-        >>> attributes = NameOrderedDict()
+        >>> attributes = NameList()
         >>> attributes.append(AttributeInfo("gender", enum=["female", "male"]))
         >>> keypoints2d_subcatalog = Keypoints2DSubcatalog()
         >>> keypoints2d_subcatalog.is_tracking = True
@@ -92,23 +89,19 @@ class Keypoints2DSubcatalog(  # pylint: disable=too-many-ancestors
         Keypoints2DSubcatalog(
           (is_tracking): True,
           (keypoints): [...],
-          (categories): NameOrderedDict {...},
-          (attributes): NameOrderedDict {...}
+          (categories): NameList [...],
+          (attributes): NameList [...]
         )
 
     """
 
+    _keypoints: List[KeypointsInfo] = attr(key="keypoints")
+
     def __init__(self, is_tracking: bool = False) -> None:
         SubcatalogBase.__init__(self)
         IsTrackingMixin.__init__(self, is_tracking)
         self._keypoints: List[KeypointsInfo] = []
 
-    def _loads(self, contents: Dict[str, Any]) -> None:
-        super()._loads(contents)
-        self._keypoints = []
-        for keypoint in contents["keypoints"]:
-            self._keypoints.append(KeypointsInfo.loads(keypoint))
-
     @property
     def keypoints(self) -> List[KeypointsInfo]:
         """Return the KeypointsInfo of the Subcatalog.
@@ -204,14 +197,10 @@ class Keypoints2DSubcatalog(  # pylint: disable=too-many-ancestors
             }
 
         """
-        contents: Dict[str, Any] = super().dumps()
-        if self._keypoints:
-            contents["keypoints"] = [keypoint.dumps() for keypoint in self._keypoints]
-        return contents
+        return self._dumps()
 
 
-@TypeRegister(LabelType.KEYPOINTS2D)
-class LabeledKeypoints2D(Keypoints2D, _LabelBase):  # pylint: disable=too-many-ancestors
+class LabeledKeypoints2D(_LabelBase, Keypoints2D):  # pylint: disable=too-many-ancestors
     """This class defines the concept of 2D keypoints label.
 
     :class:`LabeledKeypoints2D` is the 2D keypoints type of label,
@@ -250,6 +239,7 @@ class LabeledKeypoints2D(Keypoints2D, _LabelBase):  # pylint: disable=too-many-a
 
     _repr_type = ReprType.SEQUENCE
     _repr_attrs = _LabelBase._repr_attrs
+    _attrs_base: Keypoints2D = attr_base(key="keypoints2d")
 
     def __init__(
         self,
@@ -259,13 +249,9 @@ class LabeledKeypoints2D(Keypoints2D, _LabelBase):  # pylint: disable=too-many-a
         attributes: Optional[Dict[str, Any]] = None,
         instance: Optional[str] = None,
     ) -> None:
-        super().__init__(keypoints)
+        Keypoints2D.__init__(self, keypoints)  # type: ignore[arg-type]
         _LabelBase.__init__(self, category, attributes, instance)
 
-    def _loads(self, contents: Dict[str, Any]) -> None:  # type: ignore[override]
-        super()._loads(contents["keypoints2d"])
-        _LabelBase._loads(self, contents)
-
     @classmethod
     def loads(cls: Type[_T], contents: Dict[str, Any]) -> _T:  # type: ignore[override]
         """Loads a LabeledKeypoints2D from a dict containing the information of the label.
@@ -321,7 +307,4 @@ class LabeledKeypoints2D(Keypoints2D, _LabelBase):  # pylint: disable=too-many-a
             }
 
         """
-        contents = _LabelBase.dumps(self)
-        contents["keypoints2d"] = super().dumps()
-
-        return contents
+        return self._dumps()
