@@ -10,11 +10,7 @@ from ...dataset import Data, Dataset
 from ...exception import ModuleImportError
 from ...label import LabeledBox2D
 
-_SEGMENT_NAMES = (
-    "train",
-    "trainval",
-    "val",
-)
+_SEGMENT_NAMES = ("train", "val")
 DATASET_NAME = "VOC2012ActionClassification"
 
 
@@ -35,7 +31,6 @@ def VOC2012ActionClassification(path: str) -> Dataset:
             ImageSets/
                 Action/
                     train.txt
-                    trainval.txt
                     val.txt
                     ...
                 ...
@@ -48,9 +43,10 @@ def VOC2012ActionClassification(path: str) -> Dataset:
         Loaded :class: `~tensorbay.dataset.dataset.Dataset` instance.
 
     """
-    annotation_path = os.path.join(path, "Annotations")
-    image_path = os.path.join(path, "JPEGImages")
-    action_path = os.path.join(path, "ImageSets", "Action")
+    root_path = os.path.abspath(os.path.expanduser(path))
+    annotation_path = os.path.join(root_path, "Annotations")
+    image_path = os.path.join(root_path, "JPEGImages")
+    action_path = os.path.join(root_path, "ImageSets", "Action")
 
     dataset = Dataset(DATASET_NAME)
     dataset.load_catalog(os.path.join(os.path.dirname(__file__), "catalog.json"))
@@ -68,7 +64,7 @@ def _get_data(filename: str, image_path: str, annotation_path: str) -> Data:
     try:
         import xmltodict  # pylint: disable=import-outside-toplevel
     except ModuleNotFoundError as error:
-        raise ModuleImportError(error.name) from error  # type: ignore[arg-type]
+        raise ModuleImportError(module_name=error.name) from error
 
     data = Data(os.path.join(image_path, f"{filename}.jpg"))
     box2d = []
