@@ -10,12 +10,8 @@ from xml.etree import ElementTree
 from ...dataset import Data, Dataset
 from ...label import LabeledBox2D
 
-_SEGMENT_NAMES = (
-    "train",
-    "trainval",
-    "val",
-)
-_BOOLEAN_ATTRIBUTES = {"occluded", "pose", "truncated"}
+_SEGMENT_NAMES = ("train", "val")
+_BOOLEAN_ATTRIBUTES = {"occluded", "difficult", "truncated"}
 DATASET_NAME = "VOC2012Detection"
 
 
@@ -36,7 +32,6 @@ def VOC2012Detection(path: str) -> Dataset:
             ImageSets/
                 Main/
                     train.txt
-                    trainval.txt
                     val.txt
                     ...
                 ...
@@ -49,9 +44,10 @@ def VOC2012Detection(path: str) -> Dataset:
         Loaded :class: `~tensorbay.dataset.dataset.Dataset` instance.
 
     """
-    annotation_path = os.path.join(path, "Annotations")
-    image_path = os.path.join(path, "JPEGImages")
-    main_path = os.path.join(path, "ImageSets", "Main")
+    root_path = os.path.abspath(os.path.expanduser(path))
+    annotation_path = os.path.join(root_path, "Annotations")
+    image_path = os.path.join(root_path, "JPEGImages")
+    main_path = os.path.join(root_path, "ImageSets", "Main")
 
     dataset = Dataset(DATASET_NAME)
     dataset.load_catalog(os.path.join(os.path.dirname(__file__), "catalog.json"))
